@@ -1,10 +1,9 @@
 import re
-import string
 import warnings
 from typing import List
 
 from ._builtin import DeasciifierBuiltin, NormBuiltin
-
+import pandas as pd 
 
 class Normalizer:
     @staticmethod
@@ -31,7 +30,15 @@ class Normalizer:
         >>> Normalizer.lower_case("Ex: İIĞÜÖŞÇ")
         'ex: iığüöşç'
         """
-        turkish_lowercase_dict = {"İ": "i", "I": "ı", "Ğ": "ğ", "Ü": "ü", "Ö": "ö", "Ş": "ş", "Ç": "ç"}
+        turkish_lowercase_dict = {
+            "İ": "i",
+            "I": "ı",
+            "Ğ": "ğ",
+            "Ü": "ü",
+            "Ö": "ö",
+            "Ş": "ş",
+            "Ç": "ç",
+        }
         for k, v in turkish_lowercase_dict.items():
             text = text.replace(k, v)
         return text.lower()
@@ -40,7 +47,6 @@ class Normalizer:
     def remove_punctuations(text: str) -> str:
         """
         Removes punctuations (!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~) from the given string.
-
         This function removes all the punctuation characters from the given text.
 
         Parameters
@@ -59,16 +65,22 @@ class Normalizer:
         >>> Normalizer.remove_punctuations("#Merhaba, Dünya!")
         'Merhaba Dünya'
         """
-        text = " ".join([word for word in text.split() if '@' not in word])
-        text = re.sub(r"(@\[A-Za-z0-9]+)|([^0-9A-Za-zğüşıöçĞÜŞİÖÇ0-9 \t])|(\w+:\/\/\S+)|^rt|http.+?", "", text)
-        text = re.sub(r'''      
+        text = " ".join([word for word in text.split() if "@" not in word])
+        text = re.sub(
+            r"(@\[A-Za-z0-9]+)|([^0-9A-Za-zğüşıöçĞÜŞİÖÇ0-9 \t])|(\w+:\/\/\S+)|^rt|http.+?",
+            "",
+            text,
+        )
+        text = re.sub(
+            r"""      
                     \W+       # Bir veya daha fazla sözcük olmayan karakter
                     \s*       # artı sıfır veya daha fazla boşluk karakteri,
-                    ''',
-                    ' ',
-                    text,
-                    flags=re.VERBOSE)
-        
+                    """,
+            " ",
+            text,
+            flags=re.VERBOSE,
+        )
+
         return text
 
     @staticmethod
@@ -140,13 +152,19 @@ class Normalizer:
         def convert_number(match):
             number = float(match.group(0).replace(",", "."))
             if number >= 1e21:
-                return warnings.warn("The number is too big to convert it to words in Turkish language.")
+                return warnings.warn(
+                    "The number is too big to convert it to words in Turkish language."
+                )
             elif number == int(number):
                 return NormBuiltin.number_to_word(number=int(number))
             else:
-                return warnings.warn("In Turkish language, decimal numbers are expressed with commas.")
+                return warnings.warn(
+                    "In Turkish language, decimal numbers are expressed with commas."
+                )
 
-        return re.sub(r"[-+]?\d*.\d+|\d+", convert_number, text.replace(",", " virgül ")).lstrip()
+        return re.sub(
+            r"[-+]?\d*.\d+|\d+", convert_number, text.replace(",", " virgül ")
+        ).lstrip()
 
     @staticmethod
     def deasciify(input: List[str]) -> List[str]:
@@ -199,3 +217,86 @@ class Normalizer:
         translationTable = str.maketrans("ğĞıİöÖüÜşŞçÇ", "gGiIoOuUsScC")
         result = text.translate(translationTable)
         return result
+
+    @staticmethod
+    def remove_numbers(text):
+        """
+        Removes numerical expressions from a given text.
+
+        This function removes all numerical expressions from a given text, including
+        integers, decimals, and signed integers/decimals.
+
+        Parameters
+        ----------
+        text : str
+            The text to remove numerical expressions from
+
+        Returns
+        -------
+        cleaned_text : str
+            The cleaned text without any numerical expressions
+
+        Example
+        -------
+        >>> text = "Bu cümle 12.34 ile başlıyor ve 56 ile bitiyor. 2,5 +3,5 -3,4 ile ilgili bir şeyler söyleyebiliriz."
+        >>> remove_numbers(text)
+        'Bu cümle ile başlıyor ve ile bitiyor. ile ilgili bir şeyler söyleyebiliriz.'
+        """
+        return re.sub(r"(?<!\d)[-+]?\d*\.?\d+(?!\d)\s*", "", text)
+
+    @staticmethod
+    def remove_more_space(text: str) -> str:
+        """
+        Removes extra spaces from the given text.
+
+        Parameters
+        ----------
+        text : str
+            The text to remove extra spaces from.
+
+        Returns
+        -------
+        str
+            The cleaned text without extra spaces.
+
+        Example
+        -------
+        >>> text = "Ahmet Selam,  Nerelerdeydin? Seni ÇOOOOK      ÖZLEDİK!!!"
+        >>> remove_more_space(text)
+        'Ahmet Selam, Nerelerdeydin? Seni ÇOOOOK ÖZLEDİK!!!'
+        """
+        return " ".join(text.split())
+
+    def drop_empty_values(df, column_text) -> pd.DataFrame:
+        """
+        Drop the rows from the given dataframe where the specified column_text is empty.
+
+        Parameters
+        ----------
+        df : pandas.DataFrame
+            The dataframe to be processed
+        column_text : str
+            The name of the column to be checked for empty values
+
+        Returns
+        -------
+        pandas.DataFrame
+            The cleaned dataframe without the rows containing empty column_text values
+
+        Example
+        -------
+        >>> data = {'id': [1, 2, 3, 4, 5],
+                    'name': ['Şeyma', 'Murat', 'Elif', 'Tarık Kaan', 'Erdinç'],
+                    'text': ['Bilgisayar Mühendisi', 'Doç. Dr', '', 'Yazılım Mühendisi', '']}
+        >>> df = pd.DataFrame(data)
+        >>> cleaned_df = drop_empty_values(df, 'text')
+        >>> cleaned_df
+
+        id      name             text
+        0   1   Şeyma      Bilgisayar Mühendisi
+        2   3   Murat      Doç. Dr
+        3   4   Tarık Kaan Yazılım Mühendisi
+        """
+        cleaned_df = df[df[column_text] != ""]
+
+        return cleaned_df
